@@ -16,10 +16,10 @@ from .misc import update_if_not_none, update_key_if_none, update_attr_if_none, q
     update_key_if_not_none, source_to_function
 from .recast_exceptions import rethrow_as, silence_excs, catch_exception, log_exceptions, \
     raises_exception
-from .overloading import overload
+from .overloading import overload, class_or_instancemethod
 
 __all__ = [
-    'overload',
+    'overload', 'class_or_instancemethod',
     'update_if_not_none', 'DocsFromParent', 'update_key_if_none', 'queue_iterator',
     'update_attr_if_none', 'update_key_if_not_none', 'source_to_function',
     'hint_with_length', 'SelfClosingGenerator', 'exhaust', 'chain',
