@@ -1,3 +1,4 @@
+import copy
 import typing as tp
 
 from satella.coding.decorators import wraps
@@ -8,6 +9,48 @@ U = tp.TypeVar('U')
 IteratorOrIterable = tp.Union[tp.Iterator[T], tp.Iterable[T]]
 
 
+def infinite_iterator(returns: tp.Optional[T] = None,
+                      return_factory: tp.Optional[tp.Callable[[], T]] = None) -> tp.Iterator[T]:
+    """
+    Return an infinite number of objects.
+
+    :param returns: object to return. Note that this will be this very object, it will
+        not be copied.
+    :param return_factory: a callable that takes 0 args and returns an element to return.
+    :return: an infinite iterator of provided values
+    """
+    while True:
+        if returns is None:
+            if return_factory is None:
+                yield None
+            else:
+                yield return_factory()
+        else:
+            yield returns
+
+
+def make_list(element: T, n: int, deep_copy: bool = False) -> tp.List[T]:
+    """
+    Make a list consisting of n times element. Element will be copied via
+    copy.copy before adding to list.
+
+    :param element: element
+    :param n: times to repeat the element
+    :param deep_copy: whether to use copy.deepcopy instead of copy.copy
+    :return: list of length n
+    """
+    output = []
+
+    if deep_copy:
+        copy_op = copy.deepcopy
+    else:
+        copy_op = copy.copy
+
+    for _ in range(n):
+        output.append(copy_op(element))
+    return output
+
+
 # shamelessly copied from
 # https://medium.com/better-programming/is-this-the-last-element-of-my-python-for-loop-784f5ff90bb5
 def is_last(lst: IteratorOrIterable) -> tp.Iterator[tp.Tuple[bool, T]]:
