@@ -70,6 +70,7 @@ class ComparableAndHashableBy(metaclass=ABCMeta):
     >>>
     >>> assert Vector() > Vector()
     """
+    __slots__ = ()
 
     @property
     @abstractmethod
@@ -99,6 +100,36 @@ class ComparableAndHashableBy(metaclass=ABCMeta):
         return getattr(self, self._COMPARABLE_BY) >= getattr(other, other._COMPARABLE_BY)
 
 
+class ComparableAndHashableByInt(metaclass=ABCMeta):
+    """
+    A mix-in. Provides comparision (lt, gt, ge, le, eq) and hashing by __int__ of this class.
+    """
+
+    __slots__ = ()
+
+    @abstractmethod
+    def __int__(self) -> int:
+        ...
+
+    def __hash__(self):
+        return hash(int(self))
+
+    def __eq__(self, other: 'ComparableAndHashableByInt') -> bool:
+        return int(self) == int(other)
+
+    def __lt__(self, other: 'ComparableAndHashableByInt') -> bool:
+        return int(self) < int(other)
+
+    def __le__(self, other: 'ComparableAndHashableByInt') -> bool:
+        return int(self) <= int(other)
+
+    def __gt__(self, other: 'ComparableAndHashableByInt') -> bool:
+        return int(self) > int(other)
+
+    def __ge__(self, other: 'ComparableAndHashableByInt') -> bool:
+        return int(self) >= int(other)
+
+
 class OmniHashableMixin(metaclass=ABCMeta):
     """
     A mix-in. Provides hashing and equal comparison for your own class using specified fields.
@@ -128,7 +159,7 @@ class OmniHashableMixin(metaclass=ABCMeta):
 
     @property
     @abstractmethod
-    def _HASH_FIELDS_TO_USE(self) -> tp.Tuple[str]:
+    def _HASH_FIELDS_TO_USE(self) -> tp.Union[str, tp.Sequence[str]]:
         """
         Return the sequence of names of properties and attributes
         that will be used for __eq__ and __hash__
